mypersonaldev-python
====================

**mypersonaldev-python** (or, as a python package, **mypersonaldev**) is open-source personal development software.

License
-------

Copyright (c) 2011 MyPersonalDev Inc.

Licensed under the Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0.
